summaryrefslogtreecommitdiffstats
path: root/cc/math_util.h
diff options
context:
space:
mode:
authorenne@chromium.org <enne@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-10-22 23:09:55 +0000
committerenne@chromium.org <enne@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-10-22 23:09:55 +0000
commit96baf3e81b1df4b0836d70c3cded9795e63fa789 (patch)
tree4332d128a05777ae34641ca2f185b7b548330b8d /cc/math_util.h
parent1597399122fa6d8343dc6d5cdb771f95908c09b1 (diff)
downloadchromium_src-96baf3e81b1df4b0836d70c3cded9795e63fa789.zip
chromium_src-96baf3e81b1df4b0836d70c3cded9795e63fa789.tar.gz
chromium_src-96baf3e81b1df4b0836d70c3cded9795e63fa789.tar.bz2
cc: Rename cc classes and members to match filenames
Fixed reland of https://chromiumcodereview.appspot.com/11189043/ TBR=jam@chromium.org,jamesr@chromium.org BUG=155413 Review URL: https://codereview.chromium.org/11231054 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@163429 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'cc/math_util.h')
-rw-r--r--cc/math_util.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/cc/math_util.h b/cc/math_util.h
index f0a36ab..da3ba08 100644
--- a/cc/math_util.h
+++ b/cc/math_util.h
@@ -38,7 +38,7 @@ struct HomogeneousCoordinate {
if (w == 1)
return FloatPoint(x, y);
// For now, because this code is used privately only by CCMathUtil, it should never be called when w == 0, and we do not yet need to handle that case.
DCHECK(w);
double invW = 1.0 / w;
return FloatPoint(x * invW, y * invW);
@@ -49,7 +49,7 @@ struct HomogeneousCoordinate {
if (w == 1)
return FloatPoint3D(x, y, z);
// For now, because this code is used privately only by CCMathUtil, it should never be called when w == 0, and we do not yet need to handle that case.
DCHECK(w);
double invW = 1.0 / w;
return FloatPoint3D(x * invW, y * invW, z * invW);
@@ -61,7 +61,7 @@ struct HomogeneousCoordinate {
double w;
};
-class CCMathUtil {
+class MathUtil {
public:
// Background: WebTransformationMatrix code in WebCore does not do the right thing in
@@ -38,7 +38,7 @@ struct HomogeneousCoordinate {
if (w == 1)
return FloatPoint(x, y);
- // For now, because this code is used privately only by CCMathUtil, it should never be called when w == 0, and we do not yet need to handle that case.
+ // For now, because this code is used privately only by MathUtil, it should never be called when w == 0, and we do not yet need to handle that case.
DCHECK(w);
double invW = 1.0 / w;
@@ -49,7 +49,7 @@ struct HomogeneousCoordinate {
if (w == 1)
return FloatPoint3D(x, y, z);
- // For now, because this code is used privately only by CCMathUtil, it should never be called when w == 0, and we do not yet need to handle that case.
+ // For now, because this code is used privately only by MathUtil, it should never be called when w == 0, and we do not yet need to handle that case.
DCHECK(w);
double invW = 1.0 / w;